import { useCurrentAppModule } from '../app';
import { useFeatures } from './useFeatures';
/**
 * Custom hook that returns the current app features and provides a function to toggle a feature.
 * @returns An object containing the current app features, a function to toggle a feature, and any error that occurred.
 */
export const useCurrentAppFeatures = () => {
    const { module, error: moduleError } = useCurrentAppModule('featureFlag');
    const { features, toggleFeature, error } = useFeatures(module);
    return {
        features,
        toggleFeature,
        error: error !== null && error !== void 0 ? error : moduleError,
    };
};
//# sourceMappingURL=useCurrentAppFeatures.js.map